"use strict";
var fs = require('fs');
function findFiles(dir, match) {
    if (match === void 0) { match = /\.d\.ts$/; }
    if (!dir || typeof dir !== 'string') {
        throw new TypeError('Invalid directory');
    }
    if (!(match instanceof RegExp)) {
        throw new TypeError('Invalid match regexp');
    }
    return getMatches(dir, match);
}
exports.findFiles = findFiles;
/**
 * Iterate over directories and find all matching files (synchronous)
 * @param {string} dir
 * @param {RegExp} match
 * @returns {string[]}
 */
function getMatches(dir, match) {
    var files = [];
    var dirs = [];
    // get list of current dir's files, and file by type
    fs.readdirSync(dir).sort().forEach(function (file) {
        var path = dir + "/" + file;
        var stat = fs.statSync(path);
        if (!stat)
            return;
        if (stat.isFile()) {
            files.push(path);
        }
        else if (stat.isDirectory()) {
            dirs.push(path);
        }
        else {
            console.warn('DBG: Unknown file', stat);
        }
    });
    // save matched files
    var matches = files.filter(function (file) { return match.test(file); });
    // grab matches for sub-directories
    dirs.forEach(function (path) {
        var children = getMatches(path, match);
        if (children && children.length) {
            matches = matches.concat(children);
        }
    });
    return matches;
}
//# sourceMappingURL=find-files.js.map