import dts = dtsBuilder;

declare module 'dtsBuilder' {
  export = dtsBuilder;
}

declare namespace dtsBuilder {
  
  /*****************************************************************************/
  export interface Bundle {
      /**
       * Bundle name. Used for d.ts filename and the wrapping namespace.
       * @type {string}
       */
      name: string;
      /**
       * If specified, library will exported as the given value, as an alias together
       * with the original name.
       * @type {string}
       */
      alias?: string;
      /**
       * Location in which to search for *.d.ts files
       * @type {string}
       */
      sourceDir: string;
      /**
       * Location in which to save the output, under the name: `${name}.d.ts`
       * @type {string}
       */
      destDir: string;
      /**
       * List of external d.ts files that will be copied to the destination
       * directory, and will be referenced from withing the main d.ts file
       * @type {Array<string>}
       */
      externals?: Array<string>;
  }
  /**
   * Global verbose on/off switch. Import and set to `false` to remove
   * all debug output except for Exceptions.
   * @type {boolean}
   */
  export let DTSBuilderVerbose: boolean;
  /**
   * Receives a list of Bundles and generates the d.ts file according
   * to bundle configuration.
   * @param {Array<Bundle>} bundles
   */
  export function generateBundles(bundles: Array<Bundle>): void;
  
  /**
   * @link http://stackoverflow.com/a/14387791
   * @param {string} source filename
   * @param {string} target filename
   * @param {Function} cb
   */
  export function copyFile(source: string, target: string, cb: (err: NodeJS.ErrnoException, target: string) => any): void;
  
  export function findFiles(dir: string, match?: RegExp): Array<string>;
  
  export const reference: RegExp;
  export const externalModule: RegExp;
  export const externalReExports: RegExp;
  export const internalModule: RegExp;
  export const internalModuleParts: RegExp;
  export const defaultExport: RegExp;
  export const defaultsFromNs: RegExp;
  export const exportDeclarations: RegExp;
  
}